--
-- UnimogAllrad
-- Specialization for Allrad
--
-- by modelleicher
-- www.schwabenmodding.bplaced.net
-- MP Fhig!


UnimogAllrad = {};

function UnimogAllrad.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function UnimogAllrad:load(xmlFile)

    self.allradState = UnimogAllrad.allradState;

    self.JD7530AllradActive = false;
	 
	self.wellenCount = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.Allradwellen.Wellen#count"), 0);	 
	self.Wellen = {}
	if self.wellenCount ~= 0 and self.wellenCount ~= nil then
	    for i=1, self.wellenCount do
	        local Welle = string.format("vehicle.Allradwellen.Welle%d", i)
		    self.Wellen[i] = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, Welle .. "#index"));
	    end;
	end;
	self.hudAllradPosX = 0.90;
    self.hudAllradWidth = 0.08;
    self.hudAllradPosY = 0.56;
    self.hudAllradHeight = 0.08;
	self.infoPanelAllradPath = Utils.getFilename("allrad_symbol.png", self.baseDirectory);
	self.hudAllradOverlay = Overlay:new("hudAllradOverlay", self.infoPanelAllradPath, self.hudAllradPosX, self.hudAllradPosY, self.hudAllradWidth, self.hudAllradHeight);
	self.showhudAllrad = false;

end;

function UnimogAllrad:delete()
    if self.hudAllradOverlay ~= nil then
		self.hudAllradOverlay:delete();
	end;
end;

function UnimogAllrad:readStream(streamId, connection)  
     self:allradState(streamReadBool(streamId), true);  
end;

function UnimogAllrad:writeStream(streamId, connection)  
    streamWriteBool(streamId, self.JD7530AllradActive);  
end;

function UnimogAllrad:mouseEvent(posX, posY, isDown, isUp, button)
end;
function UnimogAllrad:keyEvent(unicode, sym, modifier, isDown)
end;

function UnimogAllrad:allradState(state, noEventSend)  
    AllradStateEvent.sendEvent(self, state, noEventSend);	
    self.JD7530AllradActive = state;
end;

function UnimogAllrad:update(dt)
    if self:getIsActiveForInput() then  
		if InputBinding.hasEvent(InputBinding.UnimogAllrad) then
		   	self.JD7530AllradActive = not self.JD7530AllradActive;
		end;
    end;	
	if self:getIsActive() then	
   		if self.JD7530AllradActive == true then
			self.showhudAllrad = true;		
			self.wheels[1].driveMode =2
		 	self.wheels[2].driveMode =2
		 	self.wheels[3].driveMode =2
		 	self.wheels[4].driveMode =2			
		else
			self.showhudAllrad = false;
		 	self.wheels[1].driveMode =0
			self.wheels[2].driveMode =0
			self.wheels[3].driveMode =2
			self.wheels[4].driveMode =2		
		end; 
	    if self.wellenCount ~= 0 and self.wellenCount ~= nil then
	      local getRx, getRy, getRz = getRotation(self.wheels[3].repr);
	      for i=1, self.wellenCount do
	         setRotation(self.Wellen[i], 0, 0, getRx);
	      end;
	    end;		
    end; 
end;

function UnimogAllrad:draw()
g_currentMission:addExtraPrintText("Allrad an/abschalten Taste: ".. InputBinding.getKeyNamesOfDigitalAction(InputBinding.UnimogAllrad));
   if self.showhudAllrad == true then
      	self.hudAllradOverlay:render();
   end;
end;

AllradStateEvent = {};
AllradStateEvent_mt = Class(AllradStateEvent, Event);

InitEventClass(AllradStateEvent, "AllradStateEvent");

function AllradStateEvent:emptyNew() 
    local self = Event:new(AllradStateEvent_mt );
    self.className="AllradStateEvent";
    return self;
end;

function AllradStateEvent:new(vehicle, state) 
    self.vehicle = vehicle;
    self.state = state;
    return self;
end;

function AllradStateEvent:readStream(streamId, connection)  
    local id = streamReadInt32(streamId); 
    self.state = streamReadBool(streamId); 
    self.vehicle = networkGetObject(id); 
    self:run(connection);  
end;

function AllradStateEvent:writeStream(streamId, connection)   
    streamWriteInt32(streamId, networkGetObjectId(self.vehicle));	
    streamWriteBool(streamId, self.state );   
end;

function AllradStateEvent:run(connection)  
    self.vehicle:allradState(self.state, true);
	if not connection:getIsServer() then  
		g_server:broadcastEvent(AllradStateEvent:new(self.vehicle, self.state), nil, connection, self.object);
	end;
end;

function AllradStateEvent.sendEvent(vehicle, state, noEventSend)  
	if noEventSend == nil or noEventSend == false then
		if g_server ~= nil then  
			g_server:broadcastEvent(AllradStateEvent:new(vehicle, state), nil, nil, vehicle);
		else 
			g_client:getServerConnection():sendEvent(AllradStateEvent:new(vehicle, state));
		end;
	end;
end;

